@@ -291,7 +291,7 @@ EventDeviceOffHook(InputInfoPtr pInfo)
 }
 
 /**
- * Test if the device on the file descriptior is recognized as touchpad
+ * Test if the device on the file descriptor is recognized as touchpad
  * device. Required bits for touchpad recognition are:
  * - ABS_X + ABS_Y for absolute axes
  * - ABS_PRESSURE or BTN_TOUCH
@@ -418,7 +418,7 @@ event_get_abs(struct libevdev *evdev, int code,
     *min = abs->minimum;
     *max = abs->maximum;
 
-    /* We dont trust a zero fuzz as it probably is just a lazy value */
+    /* We don't trust a zero fuzz as it probably is just a lazy value */
     if (fuzz && abs->fuzz > 0)
         *fuzz = abs->fuzz;
 #if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,30)
@@ -557,6 +557,7 @@ SynapticsReadEvent(InputInfoPtr pInfo, struct input_event *ev)
         if (rc != -EAGAIN) {
             LogMessageVerbSigSafe(X_ERROR, 0, "%s: Read error %d\n", pInfo->name,
                     errno);
+            xf86RemoveEnabledDevice(pInfo);
         } else if (proto_data->read_flag == LIBEVDEV_READ_FLAG_SYNC) {
             proto_data->read_flag = LIBEVDEV_READ_FLAG_NORMAL;
             return SynapticsReadEvent(pInfo, ev);
@@ -574,9 +575,12 @@ SynapticsReadEvent(InputInfoPtr pInfo, struct input_event *ev)
         ev->type = EV_SYN;
         ev->code = SYN_REPORT;
         ev->value = 0;
-        ev->time = last_event_time;
-    } else if (ev->type == EV_SYN)
-        last_event_time = ev->time;
+        ev->input_event_sec = last_event_time.tv_sec;
+        ev->input_event_usec = last_event_time.tv_usec;
+    } else if (ev->type == EV_SYN) {
+        last_event_time.tv_sec = ev->input_event_sec;
+        last_event_time.tv_usec = ev->input_event_usec;
+    }
 
     return TRUE;
 }
@@ -724,7 +728,7 @@ EventReadHwState(InputInfoPtr pInfo,
             case SYN_REPORT:
                 hw->numFingers = count_fingers(pInfo, comm);
                 if (proto_data->have_monotonic_clock)
-                    hw->millis = 1000 * ev.time.tv_sec + ev.time.tv_usec / 1000;
+                    hw->millis = 1000 * ev.input_event_sec + ev.input_event_usec / 1000;
                 else
                     hw->millis = GetTimeInMillis();
                 SynapticsCopyHwState(hwRet, hw);
